@@ -41,6 +41,10 @@ none - you have an external agent that handles inc for you, so
 don't bother trying it from within exmh.
 (Incorporate Mail Preferences.)"}
 
+	{inc(pophost) popHost {}	  {Mail host for POP3 protocol}
+"If this is set, inc will try to use the POP3 protocol to
+fetch your mail from a mail server."}
+
 	{editor(prog) editCmd sedit {Editor command}
 "The editor command used to compose mail messages.
 The filename will be appended to the command.
@@ -70,11 +74,6 @@ This can slow down message displaying somewhat,
 so you may prefer to do this manually by typing <Key-z>
 (WWW Preferences.)"}
 
-	{exwin(scrollbarSide) scrollbarSide {CHOICE left right} {Scrollbar side}
-"Which side the scrollbars appear on.  This
-only takes effect after you restart exmh.
-(Windows & Scrolling Preferences.)"}
-
 	{ unseenwin(on) unseenWinOn OFF {Enable Unseen Window}
 "Enables the window that summarizes your unseen messages.
 (Unseen Window Preferences.)" }
@@ -421,7 +420,7 @@ You can tune these bindings with the Bind dialog that defines
 bindings for the Text and Entry widget classes."  {
     {sedit(pref,replPrefix) replPrefix "> " {Reply insert prefix}
 "This string is prepended to lines included from the reply message
-when you use the Insert @ command."}
+when you use the Quote command."}
     {sedit(formatChoice) seditFormatMail {CHOICE OnSend OnType Never} {Format Mail default}
 "Sedit can format mail at two different times:
 OnSend converts soft line wraps to hard line breaks when you hit the send button.
@@ -493,6 +492,12 @@ wish script is used.)"}
     {sedit(autosaveInterval)   seditAutosaveInterval 60 {Seconds between auto saves}
 "This is the interval, in seconds, between automatic saves of 
 the message being edited.  Set to 0 to disable autosaving."}
+    {sedit(useFilter) seditUseFilter ON
+     {Access to Unix filter mechanism}
+"Adds the ability to filter selected text through an arbitrary Unix
+filter while composing messages.  Very handy for adding attributions,
+stripping whitespace, applying a rot13 filter (and so forth), all on the
+fly."}
     }
     Preferences_Resource sedit(wordbreakpat) seditWordBreakPat "\[\ \t/>\]"
     # Converting from boolean to choice
@@ -677,7 +682,7 @@ proc Glimpse_Init {} {
 	}
 	if [info exists glimpse(init)] { return }
 
-	if [catch {exec $glimpse(path)/glimpse -V} voutput] {
+	if {[catch {exec $glimpse(path)/glimpse -V} voutput] >= 2} {
 	    ExmhLog "$voutput"
 	    return
 	}
@@ -909,4 +914,3 @@ Compose:     Starts a mail composition"
       UnseenWinToggle
   }
 }
-
